/****************************************************************************
** Meta object code from reading C++ file 'connecteddevice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../strawberry/src/device/connecteddevice.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'connecteddevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ConnectedDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto ConnectedDevice::qt_create_metaobjectdata<qt_meta_tag_ZN15ConnectedDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ConnectedDevice",
        "TaskStarted",
        "",
        "id",
        "SongCountUpdated",
        "count",
        "DeviceConnectFinished",
        "success",
        "DeviceCloseFinished",
        "Error",
        "error",
        "BackendCloseFinished",
        "BackendTotalSongCountUpdated"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'TaskStarted'
        QtMocHelpers::SignalData<void(const int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'SongCountUpdated'
        QtMocHelpers::SignalData<void(const int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'DeviceConnectFinished'
        QtMocHelpers::SignalData<void(const QString &, const bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'DeviceCloseFinished'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'Error'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'BackendCloseFinished'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'BackendTotalSongCountUpdated'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ConnectedDevice, qt_meta_tag_ZN15ConnectedDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ConnectedDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ConnectedDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ConnectedDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ConnectedDeviceE_t>.metaTypes,
    nullptr
} };

void ConnectedDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ConnectedDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->TaskStarted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->SongCountUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->DeviceConnectFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->DeviceCloseFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->Error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->BackendCloseFinished(); break;
        case 6: _t->BackendTotalSongCountUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ConnectedDevice::*)(const int )>(_a, &ConnectedDevice::TaskStarted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectedDevice::*)(const int )>(_a, &ConnectedDevice::SongCountUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectedDevice::*)(const QString & , const bool )>(_a, &ConnectedDevice::DeviceConnectFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectedDevice::*)(const QString & )>(_a, &ConnectedDevice::DeviceCloseFinished, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectedDevice::*)(const QString & )>(_a, &ConnectedDevice::Error, 4))
            return;
    }
}

const QMetaObject *ConnectedDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ConnectedDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ConnectedDeviceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "MusicStorage"))
        return static_cast< MusicStorage*>(this);
    if (!strcmp(_clname, "enable_shared_from_this<ConnectedDevice>"))
        return static_cast< enable_shared_from_this<ConnectedDevice>*>(this);
    return QObject::qt_metacast(_clname);
}

int ConnectedDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ConnectedDevice::TaskStarted(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ConnectedDevice::SongCountUpdated(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ConnectedDevice::DeviceConnectFinished(const QString & _t1, const bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void ConnectedDevice::DeviceCloseFinished(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ConnectedDevice::Error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
