/****************************************************************************
** Meta object code from reading C++ file 'lastfmimport.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../strawberry/src/scrobbler/lastfmimport.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lastfmimport.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12LastFMImportE_t {};
} // unnamed namespace

template <> constexpr inline auto LastFMImport::qt_create_metaobjectdata<qt_meta_tag_ZN12LastFMImportE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LastFMImport",
        "UpdatePlayCount",
        "",
        "UpdateLastPlayed",
        "UpdateTotal",
        "UpdateProgress",
        "Finished",
        "FinishedWithError",
        "error",
        "FlushRequests",
        "GetRecentTracksRequestFinished",
        "QNetworkReply*",
        "reply",
        "page",
        "GetTopTracksRequestFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'UpdatePlayCount'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const int, const bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::Int, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Signal 'UpdatePlayCount'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const int)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'UpdateLastPlayed'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, const qint64)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::LongLong, 2 },
        }}),
        // Signal 'UpdateTotal'
        QtMocHelpers::SignalData<void(const int, const int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'UpdateProgress'
        QtMocHelpers::SignalData<void(const int, const int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'Finished'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FinishedWithError'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'FlushRequests'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'GetRecentTracksRequestFinished'
        QtMocHelpers::SlotData<void(QNetworkReply *, const int)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'GetTopTracksRequestFinished'
        QtMocHelpers::SlotData<void(QNetworkReply *, const int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Int, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LastFMImport, qt_meta_tag_ZN12LastFMImportE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LastFMImport::staticMetaObject = { {
    QMetaObject::SuperData::link<JsonBaseRequest::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12LastFMImportE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12LastFMImportE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12LastFMImportE_t>.metaTypes,
    nullptr
} };

void LastFMImport::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LastFMImport *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->UpdatePlayCount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 1: _t->UpdatePlayCount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 2: _t->UpdateLastPlayed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[4]))); break;
        case 3: _t->UpdateTotal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->UpdateProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->Finished(); break;
        case 6: _t->FinishedWithError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->FlushRequests(); break;
        case 8: _t->GetRecentTracksRequestFinished((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->GetTopTracksRequestFinished((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LastFMImport::*)(const QString & , const QString & , const int , const bool )>(_a, &LastFMImport::UpdatePlayCount, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LastFMImport::*)(const QString & , const QString & , const QString & , const qint64 )>(_a, &LastFMImport::UpdateLastPlayed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LastFMImport::*)(const int , const int )>(_a, &LastFMImport::UpdateTotal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LastFMImport::*)(const int , const int )>(_a, &LastFMImport::UpdateProgress, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LastFMImport::*)()>(_a, &LastFMImport::Finished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (LastFMImport::*)(const QString & )>(_a, &LastFMImport::FinishedWithError, 6))
            return;
    }
}

const QMetaObject *LastFMImport::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LastFMImport::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12LastFMImportE_t>.strings))
        return static_cast<void*>(this);
    return JsonBaseRequest::qt_metacast(_clname);
}

int LastFMImport::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = JsonBaseRequest::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void LastFMImport::UpdatePlayCount(const QString & _t1, const QString & _t2, const int _t3, const bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void LastFMImport::UpdateLastPlayed(const QString & _t1, const QString & _t2, const QString & _t3, const qint64 _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 3
void LastFMImport::UpdateTotal(const int _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void LastFMImport::UpdateProgress(const int _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void LastFMImport::Finished()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void LastFMImport::FinishedWithError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
