/****************************************************************************
** Meta object code from reading C++ file 'songloaderinserter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../strawberry/src/playlist/songloaderinserter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'songloaderinserter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18SongLoaderInserterE_t {};
} // unnamed namespace

template <> constexpr inline auto SongLoaderInserter::qt_create_metaobjectdata<qt_meta_tag_ZN18SongLoaderInserterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SongLoaderInserter",
        "Error",
        "",
        "message",
        "PreloadFinished",
        "EffectiveLoadFinished",
        "SongList",
        "songs",
        "DestinationDestroyed",
        "AudioCDTracksLoadedSlot",
        "AudioCDTracksUpdatedSlot",
        "AudioCDLoadingFinishedSlot",
        "success",
        "InsertSongs"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Error'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'PreloadFinished'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EffectiveLoadFinished'
        QtMocHelpers::SignalData<void(const SongList &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'DestinationDestroyed'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'AudioCDTracksLoadedSlot'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'AudioCDTracksUpdatedSlot'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'AudioCDLoadingFinishedSlot'
        QtMocHelpers::SlotData<void(const bool)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'InsertSongs'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SongLoaderInserter, qt_meta_tag_ZN18SongLoaderInserterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SongLoaderInserter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SongLoaderInserterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SongLoaderInserterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18SongLoaderInserterE_t>.metaTypes,
    nullptr
} };

void SongLoaderInserter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SongLoaderInserter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->PreloadFinished(); break;
        case 2: _t->EffectiveLoadFinished((*reinterpret_cast<std::add_pointer_t<SongList>>(_a[1]))); break;
        case 3: _t->DestinationDestroyed(); break;
        case 4: _t->AudioCDTracksLoadedSlot(); break;
        case 5: _t->AudioCDTracksUpdatedSlot(); break;
        case 6: _t->AudioCDLoadingFinishedSlot((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->InsertSongs(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SongLoaderInserter::*)(const QString & )>(_a, &SongLoaderInserter::Error, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SongLoaderInserter::*)()>(_a, &SongLoaderInserter::PreloadFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SongLoaderInserter::*)(const SongList & )>(_a, &SongLoaderInserter::EffectiveLoadFinished, 2))
            return;
    }
}

const QMetaObject *SongLoaderInserter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SongLoaderInserter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SongLoaderInserterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SongLoaderInserter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void SongLoaderInserter::Error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SongLoaderInserter::PreloadFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SongLoaderInserter::EffectiveLoadFinished(const SongList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
