/********************************************************************************
** Form generated from reading UI file 'lastfmimportdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LASTFMIMPORTDIALOG_H
#define UI_LASTFMIMPORTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_LastFMImportDialog
{
public:
    QVBoxLayout *verticalLayout;
    QStackedWidget *stackedWidget;
    QWidget *page_start;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_start_top;
    QCheckBox *checkbox_last_played;
    QCheckBox *checkbox_playcounts;
    QLabel *label_start_bottom;
    QSpacerItem *verticalSpacer;
    QWidget *page_progress;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_progress_top;
    QProgressBar *progressbar;
    QLabel *label_progress_bottom;
    QHBoxLayout *layout_buttons;
    QSpacerItem *horizontalSpacer;
    QPushButton *button_go;
    QPushButton *button_close;
    QPushButton *button_cancel;

    void setupUi(QDialog *LastFMImportDialog)
    {
        if (LastFMImportDialog->objectName().isEmpty())
            LastFMImportDialog->setObjectName("LastFMImportDialog");
        LastFMImportDialog->resize(520, 249);
        verticalLayout = new QVBoxLayout(LastFMImportDialog);
        verticalLayout->setObjectName("verticalLayout");
        stackedWidget = new QStackedWidget(LastFMImportDialog);
        stackedWidget->setObjectName("stackedWidget");
        page_start = new QWidget();
        page_start->setObjectName("page_start");
        verticalLayout_2 = new QVBoxLayout(page_start);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_start_top = new QLabel(page_start);
        label_start_top->setObjectName("label_start_top");
        label_start_top->setWordWrap(true);

        verticalLayout_2->addWidget(label_start_top);

        checkbox_last_played = new QCheckBox(page_start);
        checkbox_last_played->setObjectName("checkbox_last_played");

        verticalLayout_2->addWidget(checkbox_last_played);

        checkbox_playcounts = new QCheckBox(page_start);
        checkbox_playcounts->setObjectName("checkbox_playcounts");

        verticalLayout_2->addWidget(checkbox_playcounts);

        label_start_bottom = new QLabel(page_start);
        label_start_bottom->setObjectName("label_start_bottom");
        label_start_bottom->setWordWrap(true);

        verticalLayout_2->addWidget(label_start_bottom);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        stackedWidget->addWidget(page_start);
        page_progress = new QWidget();
        page_progress->setObjectName("page_progress");
        verticalLayout_3 = new QVBoxLayout(page_progress);
        verticalLayout_3->setObjectName("verticalLayout_3");
        label_progress_top = new QLabel(page_progress);
        label_progress_top->setObjectName("label_progress_top");
        label_progress_top->setWordWrap(true);

        verticalLayout_3->addWidget(label_progress_top);

        progressbar = new QProgressBar(page_progress);
        progressbar->setObjectName("progressbar");
        progressbar->setValue(0);

        verticalLayout_3->addWidget(progressbar);

        label_progress_bottom = new QLabel(page_progress);
        label_progress_bottom->setObjectName("label_progress_bottom");
        label_progress_bottom->setWordWrap(true);

        verticalLayout_3->addWidget(label_progress_bottom);

        stackedWidget->addWidget(page_progress);

        verticalLayout->addWidget(stackedWidget);

        layout_buttons = new QHBoxLayout();
        layout_buttons->setObjectName("layout_buttons");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layout_buttons->addItem(horizontalSpacer);

        button_go = new QPushButton(LastFMImportDialog);
        button_go->setObjectName("button_go");

        layout_buttons->addWidget(button_go);

        button_close = new QPushButton(LastFMImportDialog);
        button_close->setObjectName("button_close");

        layout_buttons->addWidget(button_close);

        button_cancel = new QPushButton(LastFMImportDialog);
        button_cancel->setObjectName("button_cancel");

        layout_buttons->addWidget(button_cancel);


        verticalLayout->addLayout(layout_buttons);


        retranslateUi(LastFMImportDialog);

        QMetaObject::connectSlotsByName(LastFMImportDialog);
    } // setupUi

    void retranslateUi(QDialog *LastFMImportDialog)
    {
        LastFMImportDialog->setWindowTitle(QCoreApplication::translate("LastFMImportDialog", "Import data from last.fm", nullptr));
        label_start_top->setText(QCoreApplication::translate("LastFMImportDialog", "Choose data to import from last.fm", nullptr));
        checkbox_last_played->setText(QCoreApplication::translate("LastFMImportDialog", "Last played", nullptr));
        checkbox_playcounts->setText(QCoreApplication::translate("LastFMImportDialog", "Play counts", nullptr));
        label_start_bottom->setText(QCoreApplication::translate("LastFMImportDialog", "Warning: Play counts and last played from last.fm will completely replace the same data for the matched songs. Play counts will replace the data based on artist and song title for the same albums! Please backup your database before you start.", nullptr));
        label_progress_top->setText(QString());
        label_progress_bottom->setText(QString());
        button_go->setText(QCoreApplication::translate("LastFMImportDialog", "Go!", nullptr));
        button_close->setText(QCoreApplication::translate("LastFMImportDialog", "Close", nullptr));
        button_cancel->setText(QCoreApplication::translate("LastFMImportDialog", "Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class LastFMImportDialog: public Ui_LastFMImportDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LASTFMIMPORTDIALOG_H
