/****************************************************************************
** Meta object code from reading C++ file 'playlistheader.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../strawberry/src/playlist/playlistheader.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playlistheader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14PlaylistHeaderE_t {};
} // unnamed namespace

template <> constexpr inline auto PlaylistHeader::qt_create_metaobjectdata<qt_meta_tag_ZN14PlaylistHeaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlaylistHeader",
        "SectionVisibilityChanged",
        "",
        "logical_index",
        "visible",
        "MouseEntered",
        "SectionRatingLockStatusChanged",
        "HideCurrent",
        "ToggleVisible",
        "section",
        "ResetColumns",
        "SetColumnAlignment",
        "QAction*",
        "action",
        "ToggleRatingEditStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'SectionVisibilityChanged'
        QtMocHelpers::SignalData<void(const int, const bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Signal 'MouseEntered'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SectionRatingLockStatusChanged'
        QtMocHelpers::SignalData<void(const bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'HideCurrent'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'ToggleVisible'
        QtMocHelpers::SlotData<void(const int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'ResetColumns'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'SetColumnAlignment'
        QtMocHelpers::SlotData<void(QAction *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'ToggleRatingEditStatus'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlaylistHeader, qt_meta_tag_ZN14PlaylistHeaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlaylistHeader::staticMetaObject = { {
    QMetaObject::SuperData::link<StretchHeaderView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PlaylistHeaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PlaylistHeaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14PlaylistHeaderE_t>.metaTypes,
    nullptr
} };

void PlaylistHeader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlaylistHeader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->SectionVisibilityChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->MouseEntered(); break;
        case 2: _t->SectionRatingLockStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->HideCurrent(); break;
        case 4: _t->ToggleVisible((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->ResetColumns(); break;
        case 6: _t->SetColumnAlignment((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 7: _t->ToggleRatingEditStatus(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlaylistHeader::*)(const int , const bool )>(_a, &PlaylistHeader::SectionVisibilityChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistHeader::*)()>(_a, &PlaylistHeader::MouseEntered, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistHeader::*)(const bool )>(_a, &PlaylistHeader::SectionRatingLockStatusChanged, 2))
            return;
    }
}

const QMetaObject *PlaylistHeader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlaylistHeader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PlaylistHeaderE_t>.strings))
        return static_cast<void*>(this);
    return StretchHeaderView::qt_metacast(_clname);
}

int PlaylistHeader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = StretchHeaderView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void PlaylistHeader::SectionVisibilityChanged(const int _t1, const bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void PlaylistHeader::MouseEntered()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PlaylistHeader::SectionRatingLockStatusChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
